# scripthelper

Helper module for simple command line Python scripts.

The documentation with inline examples can be found in [pypi](https://pypi.org/project/scripthelper/).

## Basic usage

See [example1.py](example1.py)

It just works. Try `--verbose` and `--quiet`  command line options, too.
It uses colored log messages on a terminal.
See `--help` for more information.

## Adding other command line parameters

See [example2.py](example2.py)

Or:

See [example2b.py](example2b.py)

## Progressbar works with logging, too

See [example3.py](example3.py)

## Extended log levels can be used in modules

See [example4.py](example4.py)

See [example4module.py](example4module.py)

## You can easily preserve logs in files

See [example5.py](example5.py)

## It handles exceptions, warnings

See [example6.py](example6.py)

(The local variables will be displayed in stack trace.)

## Has built-in colored pretty printer

See [example7.py](example7.py)
